@@ -127,7 +127,7 @@ if __name__ == "__main__":
         lD = cfg["lD"]*cfg["res"]
 
     # Create sinogram
-    u_sin = np.tile(Ex.flat,A).reshape(A, cfg["size"], cfg["size"])
+    u_sin = np.tile(Ex.flat,A).reshape(A, int(cfg["size"]), int(cfg["size"]))
 
     # Apply the Rytov approximation
     u_sinR = odt.sinogram_as_rytov(u_sin)
@@ -160,7 +160,7 @@ if __name__ == "__main__":
     axes[2].set_title("RI reconstruction, line plots")
     axes[2].set_xlabel("distance [px]")
     axes[2].set_ylabel("real refractive index")
-    center = cfg["size"]/2
+    center = int(cfg["size"]/2)
     x=np.arange(cfg["size"]) - center
     axes[2].plot(x, nR[:,center,center].real, label="along x")
     axes[2].plot(x, nR[center,center,:].real, label="along z")
