@@ -16,7 +16,7 @@ The Green's function in 3D can be written as:
 
 .. math::
     G(\mathbf{r-r'}) = \\frac{ik_\mathrm{m}}{8\pi^2} \iint \!\! dpdq 
-        \\frac{1}{M}& \exp\! \\left \\lbrace i k_\mathrm{m} \\left[ 
+        \\frac{1}{M} \exp\! \\left \\lbrace i k_\mathrm{m} \\left[ 
         p(x-x') + q(y-y') + M(z-z') \\right] \\right \\rbrace
 
 with
@@ -193,7 +193,7 @@ def backpropagate_3d(uSin, angles, res, nm, lD=0, coords=None,
         divided by the incident plane wave :math:`u_0(l_\mathrm{D})`
         measured at the detector.
     angles : (A,) ndarray
-        Angular positions :math:`\phi_j` of ``uSin`` in radians.
+        Angular positions :math:`\phi_j` of `uSin` in radians.
     res : float
         Vacuum wavelength of the light :math:`\lambda` in pixels.
     nm : float
@@ -206,7 +206,7 @@ def backpropagate_3d(uSin, angles, res, nm, lD=0, coords=None,
         keyword is reserved for future versions and is not
         implemented yet.
     weight_angles : bool
-        If ``True``, weights each backpropagated projection with a factor
+        If `True`, weights each backpropagated projection with a factor
         proportional to the angular distance between the neighboring
         projections. 
         
@@ -215,16 +215,16 @@ def backpropagate_3d(uSin, angles, res, nm, lD=0, coords=None,
         
         .. versionadded:: 0.1.1
     onlyreal : bool
-        If ``True``, only the real part of the reconstructed image
+        If `True`, only the real part of the reconstructed image
         will be returned. This saves computation time.
     padding : tuple of bool
         Pad the input data to the second next power of 2 before
         Fourier transforming. This reduces artifacts and speeds up
         the process for input image sizes that are not powers of 2.
-        The default is padding in x and y: ``padding=(True, True)``.
+        The default is padding in x and y: `padding=(True, True)`.
         For padding only in x-direction (e.g. for cylindrical
-        symmetries), set ``padding`` to ``(True, False)``. To turn off
-        padding, set it to ``(False, False)``.
+        symmetries), set `padding` to `(True, False)`. To turn off
+        padding, set it to `(False, False)`.
     padfac : float
         Increase padding size of the input data. A value greater
         than one will trigger padding to the second-next power of
@@ -238,14 +238,14 @@ def backpropagate_3d(uSin, angles, res, nm, lD=0, coords=None,
         approximation, where an approximat zero in the phase might
         translate to 2πi due to the unwrapping algorithm. In that
         case, this value should be a multiple of 2πi. 
-        If ``padval`` is ``None``, then the edge values are used for
+        If `padval` is `None`, then the edge values are used for
         padding (see documentation of :func:`numpy.pad`).
     order : int between 0 and 5
         Order of the interpolation for rotation.
         See :func:`scipy.ndimage.interpolation.rotate` for details.
     dtype : dtype object or argument for :func:`numpy.dtype`
         The data type that is used for calculations (float or double).
-        Defaults to ``numpy.float``.
+        Defaults to `numpy.float`.
     num_cores : int
         The number of cores to use for parallel operations. This value
         defaults to the number of cores on the system.
@@ -255,15 +255,15 @@ def backpropagate_3d(uSin, angles, res, nm, lD=0, coords=None,
         .. versionadded:: 0.1.5
         
     copy : bool
-        Copy input sinogram ``uSin`` for data processing. If ``copy``
-        is set to ``False``, then ``uSin`` will be overridden.
+        Copy input sinogram `uSin` for data processing. If `copy`
+        is set to `False`, then `uSin` will be overridden.
         
         .. versionadded:: 0.1.5
         
-    jmc, jmm : instance of :func:`multiprocessing.Value` or ``None``
+    jmc, jmm : instance of :func:`multiprocessing.Value` or `None`
         The progress of this function can be monitored with the 
-        :mod:`jobmanager` package. The current step ``jmc.value`` is
-        incremented ``jmm.value`` times. ``jmm.value`` is set at the 
+        :mod:`jobmanager` package. The current step `jmc.value` is
+        incremented `jmm.value` times. `jmm.value` is set at the 
         beginning.
     verbose : int
         Increment to increase verbosity.
@@ -271,7 +271,7 @@ def backpropagate_3d(uSin, angles, res, nm, lD=0, coords=None,
 
     Returns
     -------
-    f : ndarray of shape (Nx, Ny, Nx), complex if ``onlyreal==False``
+    f : ndarray of shape (Nx, Ny, Nx), complex if `onlyreal==False`
         Reconstructed object function :math:`f(\mathbf{r})` as defined
         by the Helmholtz equation.
         :math:`f(x,z) = 
@@ -351,7 +351,9 @@ def backpropagate_3d(uSin, angles, res, nm, lD=0, coords=None,
 
     # lengths of the input data
     (la, lny, lnx) = sinogram.shape
-    ln = max(lnx, lny)
+    # The z-size of the output array must match the x-size.
+    # The rotation is performed about the y-axis (lny).
+    ln = lnx
 
     # We perform padding before performing the Fourier transform.
     # This gets rid of artifacts due to false periodicity and also
@@ -378,7 +380,7 @@ def backpropagate_3d(uSin, angles, res, nm, lD=0, coords=None,
     padyl = np.int(np.ceil(pady / 2))
     padyr = np.int(pady - padyl)
     padxl = np.int(np.ceil(padx / 2))
-    padxr = np.int(padx - padyl)
+    padxr = np.int(padx - padxl)
 
     #TODO: This padding takes up a lot of memory. Move it to a separate
     # for loop or to the main for-loop.
