@@ -427,12 +427,12 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
         divided by the incident plane wave :math:`u_0(l_\mathrm{D})`
         measured at the detector.
     angles : ndarray of shape (A,3) or 1D array of length A
-        If the shape is (A,3), then ``angles`` consists of vectors
+        If the shape is (A,3), then `angles` consists of vectors
         on the unit sphere that correspond to the direction
         of illumination and acquisition (s₀). If the shape is (A,),
-        then ``angles`` is  a one-dimensional array of angles in radians
+        then `angles` is  a one-dimensional array of angles in radians
         that determines the angular position :math:`\phi_j`.
-        In both cases, ``tilted_axis`` must be set according to the
+        In both cases, `tilted_axis` must be set according to the
         tilt of the rotational axis.
     res : float
         Vacuum wavelength of the light :math:`\lambda` in pixels.
@@ -451,7 +451,7 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
         keyword is reserved for future versions and is not
         implemented yet.
     weight_angles : bool
-        If ``True``, weights each backpropagated projection with a factor
+        If `True`, weights each backpropagated projection with a factor
         proportional to the angular distance between the neighboring
         projections. 
         
@@ -460,16 +460,16 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
         
         This currently only works when `angles` has the shape (A,).
     onlyreal : bool
-        If ``True``, only the real part of the reconstructed image
+        If `True`, only the real part of the reconstructed image
         will be returned. This saves computation time.
     padding : tuple of bool
         Pad the input data to the second next power of 2 before
         Fourier transforming. This reduces artifacts and speeds up
         the process for input image sizes that are not powers of 2.
-        The default is padding in x and y: ``padding=(True, True)``.
+        The default is padding in x and y: `padding=(True, True)`.
         For padding only in x-direction (e.g. for cylindrical
-        symmetries), set ``padding`` to ``(True, False)``. To turn off
-        padding, set it to ``(False, False)``.
+        symmetries), set `padding` to `(True, False)`. To turn off
+        padding, set it to `(False, False)`.
     padfac : float
         Increase padding size of the input data. A value greater
         than one will trigger padding to the second-next power of
@@ -483,14 +483,14 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
         approximation, where an approximat zero in the phase might
         translate to 2πi due to the unwrapping algorithm. In that
         case, this value should be a multiple of 2πi. 
-        If `padval`` is ``None``, then the edge values are used for
+        If `padval` is `None`, then the edge values are used for
         padding (see documentation of :func:`numpy.pad`).
     order : int between 0 and 5
         Order of the interpolation for rotation.
         See :func:`scipy.ndimage.interpolation.affine_transform` for details.
     dtype : dtype object or argument for :func:`numpy.dtype`
         The data type that is used for calculations (float or double).
-        Defaults to ``numpy.float``.
+        Defaults to `numpy.float`.
     num_cores : int
         The number of cores to use for parallel operations. This value
         defaults to the number of cores on the system.
@@ -500,15 +500,15 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
         .. versionadded:: 0.1.5
         
     copy : bool
-        Copy input sinogram ``uSin`` for data processing. If ``copy``
-        is set to ``False``, then ``uSin`` will be overridden.
+        Copy input sinogram `uSin` for data processing. If `copy`
+        is set to `False`, then `uSin` will be overridden.
         
         .. versionadded:: 0.1.5
         
-    jmc, jmm : instance of :func:`multiprocessing.Value` or ``None``
+    jmc, jmm : instance of :func:`multiprocessing.Value` or `None`
         The progress of this function can be monitored with the 
-        :mod:`jobmanager` package. The current step ``jmc.value`` is
-        incremented ``jmm.value`` times. ``jmm.value`` is set at the 
+        :mod:`jobmanager` package. The current step `jmc.value` is
+        incremented `jmm.value` times. `jmm.value` is set at the 
         beginning.
     verbose : int
         Increment to increase verbosity.
@@ -516,7 +516,7 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
 
     Returns
     -------
-    f : ndarray of shape (Nx, Ny, Nx), complex if ``onlyreal==False``
+    f : ndarray of shape (Nx, Ny, Nx), complex if `onlyreal==False`
         Reconstructed object function :math:`f(\mathbf{r})` as defined
         by the Helmholtz equation.
         :math:`f(x,z) = 
@@ -544,6 +544,12 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
     parametric representation could e.g. be a spiral between the poles
     of the unit sphere (but this kind of rotation is probably difficult
     to implement experimentally).
+
+    If you have input images with rectangular shape, e.g. Nx!=Ny and the
+    rotational axis deviates by approximately PI/2 from the axis (0,1,0), then
+    data might get cropped in the reconstruction volume. You can avoid that by
+    rotating your input data and the rotational axis by PI/2. For instance, change
+    `tilted_axis` from [1,0,0] to [0,1,0] and `np.rot90` the sinogram images.
     
     Do not use the parameter `lD` in combination with the Rytov
     approximation - the propagation is not correctly described.
@@ -655,7 +661,7 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
 
     # lengths of the input data
     (la, lny, lnx) = sinogram.shape
-    ln = max(lnx, lny)
+    ln = lnx
 
     # We do a zero-padding before performing the Fourier transform.
     # This gets rid of artifacts due to false periodicity and also
@@ -681,7 +687,7 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
     padyl = np.int(np.ceil(pady / 2))
     padyr = np.int(pady - padyl)
     padxl = np.int(np.ceil(padx / 2))
-    padxr = np.int(padx - padyl)
+    padxr = np.int(padx - padxl)
 
 
     #TODO: This padding takes up a lot of memory. Move it to a separate
@@ -944,7 +950,7 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
         # However, the rotation matrix requires [x,y,z]. Therefore, we
         # need to np.transpose the first and last axis and also invert the
         # y-axis.
-        filtered_proj = filtered_proj.transpose(2,1,0)[:,::-1,:]
+        fil_p_t = filtered_proj.transpose(2,1,0)[:,::-1,:]
 
         # get rotation matrix for this point and also rotate in plane
         _drot, drotinv = rotation_matrix_from_point_planerot(angles[aa],
@@ -958,7 +964,7 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
         # The offset "-.5" assures that we are rotating about
         # the center of the image and not the value at the center
         # of the array (this is also what `scipy.ndimage.rotate` does.
-        c = 0.5 * np.array(filtered_proj.shape) - .5
+        c = 0.5 * np.array(fil_p_t.shape) - .5
         offset = c - np.dot(drotinv, c)
         
         ## Perform rotation
@@ -967,17 +973,20 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
         # axis is arbitrarily placed in the 3d array. Rotating single
         # slices does not yield the same result as rotating the entire
         # array. Instead of using affine_transform, map_coordinates might
-        # be faster for multiple cores. 
+        # be faster for multiple cores.
+        
+        # Also undo the axis transposition that we performed previously.
+
         outarr.real += scipy.ndimage.interpolation.affine_transform(
-                                filtered_proj.real, drotinv,
+                                fil_p_t.real, drotinv,
                                 offset=offset, mode="constant",
-                                cval=0, order=intp_order)
+                                cval=0, order=intp_order).transpose(2,1,0)[:,::-1,:]
 
         if not onlyreal:
             outarr.imag += scipy.ndimage.interpolation.affine_transform(
-                                    filtered_proj.imag, drotinv,
+                                    fil_p_t.imag, drotinv,
                                     offset=offset, mode="constant",
-                                    cval=0, order=intp_order)
+                                    cval=0, order=intp_order).transpose(2,1,0)[:,::-1,:]
 
         if jmc is not None:
             jmc.value += 1
@@ -990,7 +999,4 @@ def backpropagate_3d_tilted(uSin, angles, res, nm, lD=0,
 
     gc.collect()
 
-    # Undo the axis transposition that we performed previously.
-    outarr = outarr.transpose(2,1,0)[:,::-1,:]
-
     return outarr
