@@ -119,7 +119,6 @@ def test_3d_backprop_nopadreal():
     data = np.array(r).flatten().view(float)
     assert np.allclose(data, get_results(myframe))
 
-
 def test_3d_backprop_windows():
     """
     We assume that we are not running these tests on windows.
@@ -145,7 +144,8 @@ def test_3d_backprop_real():
     r = list()
     for p in parameters:
         f = odtbrain._Back_3D.backpropagate_3d(sino, angles, padval=0,
-                                               dtype=np.float64, **p)
+                                               dtype=np.float64,
+                                               onlyreal=False, **p)
         r.append(f)
     # real
     r2 = list()
@@ -170,7 +170,7 @@ def test_3d_backprop_phase32():
         r.append(cutout(f))
     data32 = np.array(r).flatten().view(np.float32)
     data64 = test_3d_backprop_phase()
-    assert np.allclose(data32, data64, atol=2e-7)
+    assert np.allclose(data32, data64, atol=6e-7, rtol=0)
 
 
 def test_3d_mprotate():
@@ -196,8 +196,6 @@ def test_3d_mprotate():
     assert np.allclose(np.array(_shared_array).flatten().view(float), get_results(myframe))
 
 
-    
-
 if __name__ == "__main__":
     # Run all tests
     loc = locals()
